import React, { Component } from 'react';
import { Tabs, WhiteSpace, List, Flex, WingBlank, Modal, ListView } from 'antd-mobile';
import './scholarship.scss';
import { isWechat, http, api } from "@/utils";
import CategoryItem from './CategoryItem/CategoryItem.js';
import SortItem from './SortItem/SortItem.js';
import { connect } from 'react-redux';

const Item = List.Item;
const Brief = Item.Brief;

class _Scholarship extends Component {
    constructor(props) {
        super(props);
        this.state = {
            waitMoney: 0,
            cash: 123.45,
            listType: 0,
            drawCashHtml: false,
            drawCashWechat: false,
            waitMoneyDetail: false,
            codeSrc: 'https://julyedu-cdn.oss-cn-beijing.aliyuncs.com/tinypng-common/right_weixin.png',
            dataSource: new ListView.DataSource({
                rowHasChanged: (row1, row2) => row1 !== row2,
            }),
            page: 1,
            useBodyScroll: true,
            isLoading: false,
            showNoData: false,
            hasMore: true,
        }
        this.downImage = React.createRef();
        this.tabIndex = 0;
        this.searchObject = {};
        this.rData = [];
    }
    tabList = [
        { title: '课程列表', sub: '1' },
        { title: '分销榜单', sub: '2' },
    ];
    // 切换tab页签的时候触发
    // changeTab = (tab, listType) => {
    //     this.setState({
    //         listType
    //     });
    //     this.onEndReached();
    // }
    // 返回上一页
    goback = () => {
        this.props.history.push('/my');
    }
    // 关闭弹框
    closeModal = () => {
        this.setState({
            drawCashWechat: false,
            drawCashHtml: false,
            waitMoneyDetail: false,
        });
    };
    // 显示代收款提示modal
    showDetail = () => {
        this.setState({
            waitMoneyDetail: true,
        });
    }
    // 提现按钮 根据是否在微信环境中显示提示
    drawCash = () => {
        if (isWechat()) {
            this.setState({
                drawCashWechat: true
            });
        } else {
            this.setState({
                drawCashHtml: true,
            });
        }
    };
    // 去登陆
    toLogin = () => {
        this.props.history.push('/passport');
    };
    // 跳转到规则说明页
    showDocument = () => {
        this.props.history.push('/document');
    };
    // 保存二维码 TODO 失败
    saveImage = () => {
        this.downImage.current.click();
    };
    onEndReached = () => {
        if (this.state.isLoading || !this.state.hasMore) {
            return;
        }

        this.setState({
            isLoading: true,
        });

        http.get(`${api.home}/m/dist/course_list`).then((res) => {
            if (res.data.code !== 200) {
                this.setState({ isLoading: false });
                return;
            }
            if (!res.data.data.list || res.data.data.list.length === 0) {
                this.setState({ isLoading: false, hasMore: false, showNoData: this.searchObject.page === 1 });
                return;
            }
            console.log(res);

            this.searchObject.page++;

            const newData = res.data.data.list;

            this.rData = [...this.rData, ...newData];

            this.setState({
                dataSource: this.state.dataSource.cloneWithRows(this.rData),
                isLoading: false,
                // hasMore: newData.length >= 10,
                hasMore: false
            });
        })
        .catch(() => {
            this.setState({ isLoading: false });
        });
    }
    componentDidMount() {
        if (this.state.useBodyScroll) {
            document.body.style.overflow = 'auto';
        } else {
            document.body.style.overflow = 'hidden';
        }
        this.onEndReached();
    }
    render() {
        console.log(this.props);
        const row = (
            rowData,
            rowID
        ) => {
            return <CategoryItem {...rowData} key={rowID} />;
        };

        const row1 = (
            rowData, 
            rowID
        ) => {
            return <SortItem {...rowData} key={rowID} />;
        };

        const separator = (sectionID, rowID) => (
            <div key={`${sectionID}-${rowID}`}>
                <WhiteSpace />
            </div>
        );
        const {
            waitMoney,
            cash,
            listType,
            drawCashHtml,
            drawCashWechat,
            waitMoneyDetail,
            codeSrc,
        } = this.state;
        return (
            <div className={'scholarship'}>
                <div className={'account-container'}>
                    <WhiteSpace></WhiteSpace>
                    <WingBlank>
                        <Flex justify='between'>
                            <i className={'iconfont iconiconfront-68 back'} onClick={this.goback}></i>
                            <span className={"common-ft-15"}>账户资金</span>
                            <i className={'iconfont iconaccounttip tip-info'} onClick={this.showDocument}></i>
                        </Flex>
                    </WingBlank>
                    <WhiteSpace></WhiteSpace>
                    <WingBlank>
                        <span className={'common-ft-14'}>
                            可提现余额：
                        </span>
                    </WingBlank>
                    <WhiteSpace></WhiteSpace>
                    {
                        this.tabIndex === 0 ? (
                            <>
                                <WhiteSpace></WhiteSpace>
                                <Flex justify='center'>
                                    <div className={'login-check'} onClick={this.toLogin}>登录后查看</div>
                                </Flex>
                            </>
                        ) : (
                                <>
                                    <Flex justify='center' align='baseline' style={{ height: '20px', lineHeight: '20px' }}>
                                        <span className={'common-ft-25'}>{cash}</span>
                                        <span className={'common-ft-15'}>元</span>
                                    </Flex>
                                    <WhiteSpace></WhiteSpace>
                                    <Flex justify='center'>
                                        <div className={'draw-cash'} onClick={this.drawCash}>提现</div>
                                    </Flex>
                                </>
                            )
                    }
                </div>

                <div className={'over-am-list-item'} >
                    {
                        this.tabIndex === 0 ? (null) : (
                            <>
                                <div>
                                    <List>
                                        <Item
                                            arrow="horizontal"
                                            style={{ padding: '0 0 0 15px' }}
                                            onClick={this.showDetail}
                                        >
                                            <Flex direction='row' justify='between'>
                                                <span className={'common-ft-15'}>待确认金额</span>
                                                <span className={'money'}>{waitMoney}</span>
                                            </Flex>
                                        </Item>
                                    </List>
                                </div>
                                <WhiteSpace></WhiteSpace>
                            </>
                        )
                    }
                    <div style={{backgroundColor: '#FFF'}}>
                        <Tabs tabs={this.tabList}
                            initialPage={0}
                            // onChange={this.changeTab}
                            onChange={(tab, index) => {
                                this.tabIndex = index;
                                this.pageIndex = 1;
                                this.rData = [];
                                this.searchObject.page = 1;
                                this.setState(
                                  {
                                    isLoading: false,
                                    hasMore: true,
                                    dataSource: this.state.dataSource.cloneWithRows(this.rData),
                                  },
                                  () => {
                                    this.onEndReached();
                                  }
                                );
                              }}
                        >
                            <div style={{ marginTop: '15px', backgroundColor: '#FFF'}}>
                                {
                                    this.state.dataSource._cachedRowCount !== 0 ? (
                                        <ListView
                                            useBodyScroll={this.state.useBodyScroll}
                                            dataSource={this.state.dataSource}
                                            renderRow={row}
                                            renderBodyComponent={() => <div />}
                                            onEndReached={this.onEndReached}
                                            pageSize={4}
                                            onEndReachedThreshold={100}
                                        />
                                    ) : (
                                            null
                                        )
                                }

                            </div>
                            <div>
                                <Flex justify='center' align='center' className={'runtimeList'}>榜单实时更新，仅显示前50名</Flex>
                                {
                                    this.state.dataSource._cachedRowCount !== 0 ? (
                                        <ListView
                                            useBodyScroll={this.state.useBodyScroll}
                                            dataSource={this.state.dataSource}
                                            renderRow={row1}
                                            renderBodyComponent={() => <div />}
                                            onEndReached={this.onEndReached}
                                            pageSize={4}
                                            onEndReachedThreshold={100}
                                        />
                                    ) : (
                                            null
                                        )
                                }
                            </div>
                        </Tabs>
                    </div>
                </div>

                <Modal
                    visible={drawCashWechat}
                    transparent
                    maskClosable={true}
                    onClose={this.closeModal}
                    title="提现"
                    footer={[{ text: '确认', onPress: () => { this.closeModal() } }]}
                    className={'wechatModal'}
                    style={{ width: '300px' }}
                >
                    <p style={{ fontSize: '13px', color: '#666666' }}>
                        提现金额将通过微信零钱转账给您，识别下方二维码，关注【七月在线】服务号申请提现。
                    </p>
                    <WhiteSpace size='sm'></WhiteSpace>
                    <Flex justify='center'>
                        <img src={codeSrc} style={{ width: '90px', height: '90px', backgroundColor: '#666' }} alt="二维码" />
                    </Flex>
                </Modal>

                <Modal
                    visible={drawCashHtml}
                    transparent
                    maskClosable={true}
                    onClose={this.closeModal}
                    title="提现"
                    footer={[
                        { text: '取消', onPress: () => { this.closeModal() } },
                        { text: '保存二维码', onPress: () => { this.saveImage() } }
                    ]}
                    style={{ width: '300px' }}
                >
                    <p style={{ fontSize: '13px', color: '#666666' }}>
                        提现金额将通过微信零钱转账给您，请微信扫码关注【七月在线】服务号后申请提现。
                    </p>
                    <WhiteSpace size='sm'></WhiteSpace>
                    <Flex justify='center'>
                        <img src={codeSrc} style={{ width: '90px', height: '90px' }} alt="二维码" />
                    </Flex>
                    {/* <a crossOrigin='true' href={codeSrc} download='七月在线服务号' onClick={(e)=>{console.log(e)}} ref={this.downImage} ></a> */}
                </Modal>

                <Modal
                    visible={waitMoneyDetail}
                    transparent
                    maskClosable={true}
                    onClose={this.closeModal}
                    title="待确认金额"
                    footer={[
                        { text: '知道了', onPress: () => { this.closeModal() } }
                    ]}
                    style={{ width: '300px' }}
                >
                    <p style={{ fontSize: '13px', color: '#666666', textAlign: 'left', lineHeight: '20px' }}>
                        1.尚未开课的直播课程，用户购买后归属您的佣金会暂时存放在『待确认金额』中。
                    </p>
                    <p style={{ fontSize: '13px', color: '#666666', textAlign: 'left', lineHeight: '20px' }}>
                        2.该课程正式开课时，如果用户没有退款，对应的订单金额会自动转入您的账号余额，否则该佣金会自动收回。
                    </p>
                    <WhiteSpace></WhiteSpace>
                    <Flex style={{ fontSize: '13px', color: '#000' }} justify='center'>
                        <span>待确认订单详情可</span>
                        <span style={{ color: '#0099FF', marginLeft: '10px' }}>前往APP查看</span>
                    </Flex>
                </Modal>
            </div>
        )
    }
}
const mapStateToProps = (state) => {
    console.log(state);
    return {
      user: {

      },
    };
  };
  
  const mapDispatchToProps = (dispatch) => {
    return {};
  };
  
  export const Scholarship = connect(
    mapStateToProps,
    mapDispatchToProps
  )(_Scholarship);
